Crate ozlrip_decode

Crate ozlrip_decode 

Structs

Decoder
Reusable OpenZL decoder with scratch buffers and codec state.
Options
Decoder configuration.

Constants

DEFAULT_PLAN_CACHE_MAX_FRAME_BYTES

Functions

decode
Decodes one OpenZL frame into a new Vec using Options::default.
decode_into
Decodes one OpenZL frame and appends the decoded bytes to dst.
decode_into_with_options
Decodes one OpenZL frame into dst using explicit options.
decode_with_options
Decodes one OpenZL frame into a new Vec using explicit options.
inspect
Parses and validates frame metadata using Options::default.
inspect_with_options
Parses and validates frame metadata using explicit options.