decode_into

Function decode_into 

pub fn decode_into(input: &[u8], dst: &mut Vec<u8>) -> Result<usize>
Decodes one OpenZL frame and appends the decoded bytes to dst.

Returns the number of bytes appended. On error, dst is restored to its original length.