Decoder

Struct Decoder 

pub struct Decoder { /* private fields */ }
Reusable OpenZL decoder with scratch buffers and codec state.

Implementations

Source

impl Decoder

pub fn new() -> Self

Creates a decoder with Options::default.

pub fn with_options(options: Options) -> Self

Creates a decoder with explicit options.

pub fn options(&self) -> Options

pub fn limits(&self) -> Limits

pub fn load_dictionary_bundle(&mut self, bytes: &[u8]) -> Result<()>

Loads an OpenZL dictionary bundle for later dictionary-backed decode.

Currently only zstd dictionary materialization is implemented.

pub fn load_fat_bundle(&mut self, bytes: &[u8]) -> Result<()>

Loads a fat OpenZL dictionary bundle for later dictionary-backed decode.

Prefer Decoder::load_dictionary_bundle for new code.

pub fn clear_dictionary_bundles(&mut self)

Clears all loaded dictionary bundles.

pub fn decode_into(&mut self, input: &[u8], dst: &mut Vec<u8>) -> Result<usize>

Decodes one OpenZL frame and appends the decoded bytes to dst.

Returns the number of bytes appended. On error, dst is restored to its original length.

pub fn decode(&mut self, input: &[u8]) -> Result<Vec<u8>>

Decodes one OpenZL frame into a new Vec.

pub fn inspect(&self, input: &[u8]) -> Result<FrameInfo>

Parses and validates frame metadata without executing decode nodes.