pub struct Options {
pub limits: Limits,
pub plan_cache_max_frame_bytes: usize,
}Expand description
Decoder configuration.
New options should be added here instead of creating new public function variants.
Fields
limits: LimitsDefensive parser, graph, allocation, and expansion limits.
plan_cache_max_frame_bytes: usizeMaximum frame size eligible for reusable decoder plan caching.
Set to 0 to disable plan caching.